/*REXX exec to run the AFP datastream analyser*/
/* output is named with input filename and filetype LIST */
/*********************************************************************/
/*->>                                                                */
/*  AFPAN is an EXEC which produces a formatted list of AFPDS and    */
/*  MOD:CA files, showing structured fields and their values.        */
/*                                                                   */
/*  To use:                                                          */
/*          AFPAN fn  ft  <fm> (<type>                               */
/*     <type> is STREAM or blank                                     */
/*                                                                   */
/*  The output listing will be placed in fn.LST.                     */
/*                                                                   */
/*  Additional parameters that may be coded in <type> are:           */
/*  MODCA stream MO:DCA data (no x'5a' cc)                           */
/*  COMPACT (default) compact text record formatting                 */
/*  LL(nnn) report line length (default 160)                         */
/*  PAGEST(nn) starting page (counts BPGs)                           */
/*  PAGEND(nn) ending page                                           */
/*  RECEST(nn) starting record number                                */
/*  RECEND(nn) ending   record number                                */
/*  CDPDS interpret as CDPDS data                                    */
/*  NOWARN suppress warning messages                                 */
/*  the parameter LOG is automatically supplied.                     */
/*                                                                   */
/*  The MODCA option expects input of structured fields in stream    */
/* format, without x'5A' carriage controls.                          */
/*                                                                   */
/*                                                                <<-*/
/*********************************************************************/
/*                                                                   */
/*   (C) COPYRIGHT IBM CORPORATION, 1989,1991,1992,1994              */
/*                                                                   */
/*        >>>>>>>  IMPORTANT NOTICE   <<<<<<<<<<<                    */
/*                                                                   */
/*   THIS PROGRAM IS NOT SUPPORTED IN ANY WAY BY IBM.  IT HAS NOT    */
/*   BEEN SUBJECTED TO ANY FORMAL IBM TESTING AND IS DISTRIBUTED ON  */
/*   AN "AS-IS" BASIS WITHOUT ANY WARRANTY EITHER EXPRESSED OR       */
/*   IMPLIED.  THE USE OF THIS CODE OR ANY INFORMATION OR TECHNIQUES */
/*   IMPLICIT WITHIN IT IS THE SOLE RESPONSIBILITY OF THE CUSTOMER.  */
/*   SUCH USE DEPENDS UPON THE CUSTOMER'S ABILITY TO EVALUATE THE    */
/*   INFORMATION IN THE CONTEXT OF THEIR OWN PARTICULAR OPERATING    */
/*   ENVIRONMENT.  THIS CODE HAS OPERATED SUCCESSFULLY IN THE        */
/*   COMPUTING ENVIRONMENT AT THE BOULDER PROGRAMMING CENTER.        */
/*   THERE IS NO GUARANTEE THAT IT WILL OPERATE CORRECTLY ELSEWHERE. */
/*********************************************************************/
trace o
debug_names='DEBUG_LANG'
debug_values='PL1'
arg fn  '(' parm
parse upper source . . pgmn .
if fn = '?' | fn = '' then signal helpit       /* provide some help */
fn = strip(fn)
parse value FILESPEC("name",pgmn) with pgmname '.' .
pgmdriv = FILESPEC("drive",pgmn)
pgmpath = FILESPEC("path",pgmn)
call RxFuncAdd 'SysLoadFuncs','RexxUtil','SysLoadFuncs'
call SysLoadFuncs
call SysFileTree fn,'OPTNAME', 'FO'
if OPTNAME.0 = 0 then
if rc <> 0 then
 do
  say pgmname': Input file not found...'
  exit
 end
analpgm = pgmdriv || pgmpath || 'AFPANLYZ.EXE'
call SysFileTree analpgm,'ANALPATH','BO'
if ANALPATH.0 = 0 then
if rc <> 0 then
 do
  say pgmname': AFPANLYZ.EXE not found...'
  exit  8
 end
os2env = "ENVIRONMENT"
dd = 'DD:IN'
dsname = optname.1
Call Value dd,dsname,os2env;
dd = 'DD:SYSPRINT'
parse var fn fn '.' .
fn = strip(fn)
dsname = OPTNAME.1 || '.LST,APPEND(N)'
Call Value dd,dsname,os2env;
tstpos = pos('TEST',parm)
if tstpos > 0 then
 do
  run_opt = 'TEST(ALL,*,PROMPT,*)'
  parm = delstr(parm,tstpos,4)            /* remove from options */
  Call Value debug_names,debug_values,os2env
 end
 else
  run_opt = 'NOTEST'

if tstpos > 0 then                     /*  invoke debugger            */
  "pdebug /p+ " ANALPATH.1"  /LOG "parm
 else
  ANALPATH.1 '/LOG 'parm
say pgmname 'Output in 'dsname
exit rc

HELPIT:;
/*----------------------------------------------------------------*/
/* Show the Help information (from the EXEC header comments)      */
/*----------------------------------------------------------------*/
 beginhelp='-'||'>>'; endhelp='<<'||'-';
 helpstarts=no; htotal=SOURCELINE();
 DO hptr=1 TO htotal;
   hline=SOURCELINE(hptr);
   IF POS(beginhelp,hline)>0 THEN helpstarts=yes;
   ELSE DO;
     IF POS(endhelp,hline)>0 THEN hptr=1E5;
     ELSE DO;
       IF helpstarts=yes THEN DO;
         PARSE VALUE hline WITH '/*' hline '*/';
         SAY hline;
       END;
     END;
   END;
 END;
RETURN;
